@@ -75,6 +75,12 @@ struct obs_frontend_callbacks {
 	virtual obs_service_t *obs_frontend_get_streaming_service(void)=0;
 	virtual void obs_frontend_save_streaming_service()=0;
 
+	virtual bool obs_frontend_preview_program_mode_active(void)=0;
+	virtual void obs_frontend_set_preview_program_mode(bool enable)=0;
+
+	virtual obs_source_t *obs_frontend_get_current_preview_scene(void)=0;
+	virtual void obs_frontend_set_current_preview_scene(obs_source_t *scene)=0;
+
 	virtual void on_load(obs_data_t *settings)=0;
 	virtual void on_save(obs_data_t *settings)=0;
 	virtual void on_event(enum obs_frontend_event event)=0;
