@@ -196,7 +196,9 @@ void gs_device::InitCompiler()
 		ver--;
 	}
 
-	throw "Could not find any D3DCompiler libraries";
+	throw "Could not find any D3DCompiler libraries. Make sure you've "
+		"installed the <a href=\"https://obsproject.com/go/dxwebsetup\">"
+		"DirectX components</a> that OBS Studio requires.";
 }
 
 void gs_device::InitFactory(uint32_t adapterIdx)
