@@ -952,7 +952,6 @@ static bool buffer_audio(struct obs_encoder *encoder, struct audio_data *data)
 		/* use currently buffered audio instead */
 		if (v_start_ts < data->timestamp) {
 			start_from_buffer(encoder, v_start_ts);
-			goto skip_push;
 		}
 
 	} else if (!encoder->start_ts && !encoder->paired_encoder) {
@@ -962,7 +961,6 @@ static bool buffer_audio(struct obs_encoder *encoder, struct audio_data *data)
 fail:
 	push_back_audio(encoder, data, size, offset_size);
 
-skip_push:
 	profile_end(buffer_audio_name);
 	return success;
 }
