@@ -71,6 +71,8 @@ static void *scene_create(obs_data_t *settings, struct obs_source *source)
 	signal_handler_add_array(obs_source_get_signal_handler(source),
 			obs_scene_signals);
 
+	scene->id_counter = 0;
+
 	if (pthread_mutexattr_init(&attr) != 0)
 		goto fail;
 	if (pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE) != 0)
@@ -484,7 +486,10 @@ static inline void render_item(struct obs_scene_item *item)
 					-(float)item->crop.top,
 					0.0f);
 
+			gs_blend_state_push();
+			gs_blend_function(GS_BLEND_ONE, GS_BLEND_ZERO);
 			obs_source_video_render(item->source);
+			gs_blend_state_pop();
 			gs_texrender_end(item->item_render);
 		}
 	}
@@ -588,6 +593,7 @@ static void scene_load_item(struct obs_scene *scene, obs_data_t *item_data)
 	const char            *scale_filter_str;
 	struct obs_scene_item *item;
 	bool visible;
+	bool lock;
 
 	if (!source) {
 		blog(LOG_WARNING, "[scene_load_item] Source %s not found!",
@@ -608,13 +614,24 @@ static void scene_load_item(struct obs_scene *scene, obs_data_t *item_data)
 	obs_data_set_default_int(item_data, "align",
 			OBS_ALIGN_TOP | OBS_ALIGN_LEFT);
 
+	if (obs_data_has_user_value(item_data, "id"))
+		item->id = obs_data_get_int(item_data, "id");
+
 	item->rot     = (float)obs_data_get_double(item_data, "rot");
 	item->align   = (uint32_t)obs_data_get_int(item_data, "align");
 	visible = obs_data_get_bool(item_data, "visible");
+	lock = obs_data_get_bool(item_data, "locked");
 	obs_data_get_vec2(item_data, "pos",    &item->pos);
 	obs_data_get_vec2(item_data, "scale",  &item->scale);
 
+	obs_data_release(item->private_settings);
+	item->private_settings =
+		obs_data_get_obj(item_data, "private_settings");
+	if (!item->private_settings)
+		item->private_settings = obs_data_create();
+
 	set_visibility(item, visible);
+	obs_sceneitem_set_locked(item, lock);
 
 	item->bounds_type =
 		(enum obs_bounds_type)obs_data_get_int(item_data,
@@ -659,8 +676,9 @@ static void scene_load_item(struct obs_scene *scene, obs_data_t *item_data)
 	update_item_transform(item);
 }
 
-static void scene_load(void *scene, obs_data_t *settings)
+static void scene_load(void *data, obs_data_t *settings)
 {
+	struct obs_scene *scene = data;
 	obs_data_array_t *items = obs_data_get_array(settings, "items");
 	size_t           count, i;
 
@@ -676,6 +694,9 @@ static void scene_load(void *scene, obs_data_t *settings)
 		obs_data_release(item_data);
 	}
 
+	if (obs_data_has_user_value(settings, "id_counter"))
+		scene->id_counter = obs_data_get_int(settings, "id_counter");
+
 	obs_data_array_release(items);
 }
 
@@ -688,6 +709,7 @@ static void scene_save_item(obs_data_array_t *array,
 
 	obs_data_set_string(item_data, "name",         name);
 	obs_data_set_bool  (item_data, "visible",      item->user_visible);
+	obs_data_set_bool  (item_data, "locked",       item->locked);
 	obs_data_set_double(item_data, "rot",          item->rot);
 	obs_data_set_vec2 (item_data, "pos",          &item->pos);
 	obs_data_set_vec2 (item_data, "scale",        &item->scale);
@@ -699,6 +721,7 @@ static void scene_save_item(obs_data_array_t *array,
 	obs_data_set_int  (item_data, "crop_top",     (int)item->crop.top);
 	obs_data_set_int  (item_data, "crop_right",   (int)item->crop.right);
 	obs_data_set_int  (item_data, "crop_bottom",  (int)item->crop.bottom);
+	obs_data_set_int  (item_data, "id",           item->id);
 
 	if (item->scale_filter == OBS_SCALE_POINT)
 		scale_filter = "point";
@@ -713,6 +736,9 @@ static void scene_save_item(obs_data_array_t *array,
 
 	obs_data_set_string(item_data, "scale_filter", scale_filter);
 
+	obs_data_set_obj(item_data, "private_settings",
+			item->private_settings);
+
 	obs_data_array_push_back(array, item_data);
 	obs_data_release(item_data);
 }
@@ -731,6 +757,8 @@ static void scene_save(void *data, obs_data_t *settings)
 		item = item->next;
 	}
 
+	obs_data_set_int(settings, "id_counter", scene->id_counter);
+
 	full_unlock(scene);
 
 	obs_data_set_array(settings, "items", array);
@@ -1100,8 +1128,19 @@ obs_scene_t *obs_scene_duplicate(obs_scene_t *scene, const char *name,
 			new_item->bounds_align = item->bounds_align;
 			new_item->bounds = item->bounds;
 
+			new_item->toggle_visibility =
+					OBS_INVALID_HOTKEY_PAIR_ID;
+
 			obs_sceneitem_set_crop(new_item, &item->crop);
 
+			if (!new_item->item_render &&
+			    item_texture_enabled(new_item)) {
+				obs_enter_graphics();
+				new_item->item_render = gs_texrender_create(
+						GS_RGBA, GS_ZS_NONE);
+				obs_leave_graphics();
+			}
+
 			obs_source_release(source);
 		}
 	}
@@ -1160,6 +1199,28 @@ obs_sceneitem_t *obs_scene_find_source(obs_scene_t *scene, const char *name)
 	return item;
 }
 
+obs_sceneitem_t *obs_scene_find_sceneitem_by_id(obs_scene_t *scene, int64_t id)
+{
+	struct obs_scene_item *item;
+
+	if (!scene)
+		return NULL;
+
+	full_lock(scene);
+
+	item = scene->first_item;
+	while (item) {
+		if (item->id == id)
+			break;
+
+		item = item->next;
+	}
+
+	full_unlock(scene);
+
+	return item;
+}
+
 void obs_scene_enum_items(obs_scene_t *scene,
 		bool (*callback)(obs_scene_t*, obs_sceneitem_t*, void*),
 		void *param)
@@ -1307,11 +1368,14 @@ obs_sceneitem_t *obs_scene_add(obs_scene_t *scene, obs_source_t *source)
 
 	item = bzalloc(sizeof(struct obs_scene_item));
 	item->source  = source;
+	item->id      = ++scene->id_counter;
 	item->parent  = scene;
 	item->ref     = 1;
 	item->align   = OBS_ALIGN_TOP | OBS_ALIGN_LEFT;
 	item->actions_mutex = mutex;
 	item->user_visible = true;
+	item->locked = false;
+	item->private_settings = obs_data_create();
 	os_atomic_set_long(&item->active_refs, 1);
 	vec2_set(&item->scale, 1.0f, 1.0f);
 	matrix4_identity(&item->draw_transform);
@@ -1367,6 +1431,7 @@ static void obs_sceneitem_destroy(obs_sceneitem_t *item)
 			gs_texrender_destroy(item->item_render);
 			obs_leave_graphics();
 		}
+		obs_data_release(item->private_settings);
 		obs_hotkey_pair_unregister(item->toggle_visibility);
 		pthread_mutex_destroy(&item->actions_mutex);
 		if (item->source)
@@ -1738,6 +1803,27 @@ bool obs_sceneitem_set_visible(obs_sceneitem_t *item, bool visible)
 	return true;
 }
 
+bool obs_sceneitem_locked(const obs_sceneitem_t *item)
+{
+	return item ? item->locked : false;
+}
+
+bool obs_sceneitem_set_locked(obs_sceneitem_t *item, bool lock)
+{
+	if (!item)
+		return false;
+
+	if (item->locked == lock)
+		return false;
+
+	if (!item->parent)
+		return false;
+
+	item->locked = lock;
+
+	return true;
+}
+
 static bool sceneitems_match(obs_scene_t *scene, obs_sceneitem_t * const *items,
 		size_t size, bool *order_matches)
 {
@@ -1919,3 +2005,20 @@ void obs_sceneitem_defer_update_end(obs_sceneitem_t *item)
 	if (os_atomic_dec_long(&item->defer_update) == 0)
 		update_item_transform(item);
 }
+
+int64_t obs_sceneitem_get_id(const obs_sceneitem_t *item)
+{
+	if (!obs_ptr_valid(item, "obs_sceneitem_get_id"))
+		return 0;
+
+	return item->id;
+}
+
+obs_data_t *obs_sceneitem_get_private_settings(obs_sceneitem_t *item)
+{
+	if (!obs_ptr_valid(item, "obs_sceneitem_get_private_settings"))
+		return NULL;
+
+	obs_data_addref(item->private_settings);
+	return item->private_settings;
+}
