@@ -15,6 +15,9 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
 
+#include <time.h>
+#include <stdlib.h>
+
 #include "obs.h"
 #include "obs-internal.h"
 #include "graphics/vec4.h"
@@ -105,6 +108,19 @@ static inline void render_main_texture(struct obs_core_video *video,
 	gs_clear(GS_CLEAR_COLOR, &clear_color, 1.0f, 0);
 
 	set_render_size(video->base_width, video->base_height);
+
+	pthread_mutex_lock(&obs->data.draw_callbacks_mutex);
+
+	for (size_t i = 0; i < obs->data.draw_callbacks.num; i++) {
+		struct draw_callback *callback;
+		callback = obs->data.draw_callbacks.array+i;
+
+		callback->draw(callback->param,
+				video->base_width, video->base_height);
+	}
+
+	pthread_mutex_unlock(&obs->data.draw_callbacks_mutex);
+
 	obs_view_render(&obs->data.main_view);
 
 	video->textures_rendered[cur_texture] = true;
@@ -287,7 +303,7 @@ static inline void stage_output_texture(struct obs_core_video *video,
 		texture_ready = video->textures_converted[prev_texture];
 	} else {
 		texture = video->output_textures[prev_texture];
-		texture_ready = video->output_textures[prev_texture];
+		texture_ready = video->textures_output[prev_texture];
 	}
 
 	unmap_last_surface(video);
@@ -569,10 +585,11 @@ static inline void output_frame(void)
 static const char *tick_sources_name = "tick_sources";
 static const char *render_displays_name = "render_displays";
 static const char *output_frame_name = "output_frame";
-void *obs_video_thread(void *param)
+void *obs_graphics_thread(void *param)
 {
 	uint64_t last_time = 0;
 	uint64_t interval = video_output_get_frame_time(obs->video.video);
+	uint64_t frame_time_total_ns = 0;
 	uint64_t fps_total_ns = 0;
 	uint32_t fps_total_frames = 0;
 
@@ -582,10 +599,15 @@ void *obs_video_thread(void *param)
 
 	const char *video_thread_name =
 		profile_store_name(obs_get_profiler_name_store(),
-			"obs_video_thread(%g"NBSP"ms)", interval / 1000000.);
+			"obs_graphics_thread(%g"NBSP"ms)", interval / 1000000.);
 	profile_register_root(video_thread_name, interval);
 
+	srand((unsigned int)time(NULL));
+
 	while (!video_output_stopped(obs->video.video)) {
+		uint64_t frame_start = os_gettime_ns();
+		uint64_t frame_time_ns;
+
 		profile_start(video_thread_name);
 
 		profile_start(tick_sources_name);
@@ -600,18 +622,25 @@ void *obs_video_thread(void *param)
 		output_frame();
 		profile_end(output_frame_name);
 
+		frame_time_ns = os_gettime_ns() - frame_start;
+
 		profile_end(video_thread_name);
 
 		profile_reenable_thread();
 
 		video_sleep(&obs->video, &obs->video.video_time, interval);
 
+		frame_time_total_ns += frame_time_ns;
 		fps_total_ns += (obs->video.video_time - last_time);
 		fps_total_frames++;
 
 		if (fps_total_ns >= 1000000000ULL) {
 			obs->video.video_fps = (double)fps_total_frames /
 				((double)fps_total_ns / 1000000000.0);
+			obs->video.video_avg_frame_time_ns =
+				frame_time_total_ns / (uint64_t)fps_total_frames;
+
+			frame_time_total_ns = 0;
 			fps_total_ns = 0;
 			fps_total_frames = 0;
 		}
