@@ -15,6 +15,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
 
+#include "util/windows/win-registry.h"
 #include "util/windows/win-version.h"
 #include "util/platform.h"
 #include "util/dstr.h"
@@ -105,54 +106,10 @@ static void log_processor_info(void)
 	RegCloseKey(key);
 }
 
-static DWORD num_logical_cores(ULONG_PTR mask)
-{
-	DWORD     left_shift    = sizeof(ULONG_PTR) * 8 - 1;
-	DWORD     bit_set_count = 0;
-	ULONG_PTR bit_test      = (ULONG_PTR)1 << left_shift;
-
-	for (DWORD i = 0; i <= left_shift; ++i) {
-		bit_set_count += ((mask & bit_test) ? 1 : 0);
-		bit_test      /= 2;
-	}
-
-	return bit_set_count;
-}
-
 static void log_processor_cores(void)
 {
-	PSYSTEM_LOGICAL_PROCESSOR_INFORMATION info = NULL, temp = NULL;
-	DWORD len = 0;
-
-	GetLogicalProcessorInformation(info, &len);
-	if (GetLastError() != ERROR_INSUFFICIENT_BUFFER)
-		return;
-
-	info = malloc(len);
-
-	if (GetLogicalProcessorInformation(info, &len)) {
-		DWORD num            = len / sizeof(*info);
-		int   physical_cores = 0;
-		int   logical_cores  = 0;
-
-		temp = info;
-
-		for (DWORD i = 0; i < num; i++) {
-			if (temp->Relationship == RelationProcessorCore) {
-				ULONG_PTR mask = temp->ProcessorMask;
-
-				physical_cores++;
-				logical_cores += num_logical_cores(mask);
-			}
-
-			temp++;
-		}
-
-		blog(LOG_INFO, "Physical Cores: %d, Logical Cores: %d",
-				physical_cores, logical_cores);
-	}
-
-	free(info);
+	blog(LOG_INFO, "Physical Cores: %d, Logical Cores: %d",
+			os_get_physical_cores(), os_get_logical_cores());
 }
 
 static void log_available_memory(void)
@@ -233,6 +190,49 @@ static void log_aero(void)
 			aeroMessage);
 }
 
+#define WIN10_GAME_BAR_REG_KEY \
+		L"Software\\Microsoft\\Windows\\CurrentVersion\\GameDVR"
+#define WIN10_GAME_DVR_POLICY_REG_KEY \
+		L"SOFTWARE\\Policies\\Microsoft\\Windows\\GameDVR"
+#define WIN10_GAME_DVR_REG_KEY L"System\\GameConfigStore"
+#define WIN10_GAME_MODE_REG_KEY L"Software\\Microsoft\\GameBar"
+
+static void log_gaming_features(void)
+{
+	if (win_ver < 0xA00)
+		return;
+
+	struct reg_dword game_bar_enabled;
+	struct reg_dword game_dvr_allowed;
+	struct reg_dword game_dvr_enabled;
+	struct reg_dword game_dvr_bg_recording;
+	struct reg_dword game_mode_enabled;
+
+	get_reg_dword(HKEY_CURRENT_USER, WIN10_GAME_BAR_REG_KEY,
+			L"AppCaptureEnabled", &game_bar_enabled);
+	get_reg_dword(HKEY_CURRENT_USER, WIN10_GAME_DVR_POLICY_REG_KEY,
+			L"AllowGameDVR", &game_dvr_allowed);
+	get_reg_dword(HKEY_CURRENT_USER, WIN10_GAME_DVR_REG_KEY,
+			L"GameDVR_Enabled", &game_dvr_enabled);
+	get_reg_dword(HKEY_CURRENT_USER, WIN10_GAME_BAR_REG_KEY,
+			L"HistoricalCaptureEnabled", &game_dvr_bg_recording);
+	get_reg_dword(HKEY_CURRENT_USER, WIN10_GAME_MODE_REG_KEY,
+			L"AllowAutoGameMode", &game_mode_enabled);
+
+	blog(LOG_INFO, "Windows 10 Gaming Features:");
+	blog(LOG_INFO, "\tGame Bar: %s",
+			(bool)game_bar_enabled.return_value ? "On" : "Off");
+	blog(LOG_INFO, "\tGame DVR Allowed: %s",
+			(bool)game_dvr_allowed.return_value ? "Yes" : "No");
+	blog(LOG_INFO, "\tGame DVR: %s",
+			(bool)game_dvr_enabled.return_value ? "On" : "Off");
+	blog(LOG_INFO, "\tGame DVR Background Recording: %s",
+			(bool)game_dvr_bg_recording.return_value ? "On" :
+			"Off");
+	blog(LOG_INFO, "\tGame Mode: %s",
+			(bool)game_mode_enabled.return_value ? "On" : "Off");
+}
+
 void log_system_info(void)
 {
 	struct win_version_info ver;
@@ -246,6 +246,7 @@ void log_system_info(void)
 	log_windows_version();
 	log_admin_status();
 	log_aero();
+	log_gaming_features();
 }
 
 
@@ -372,12 +373,16 @@ static int get_virtual_key(obs_key_t key)
 	case OBS_KEY_BRACKETRIGHT: return VK_OEM_6;
 	case OBS_KEY_ASCIITILDE: return VK_OEM_3;
 
+	case OBS_KEY_HENKAN: return VK_CONVERT;
+	case OBS_KEY_MUHENKAN: return VK_NONCONVERT;
 	case OBS_KEY_KANJI: return VK_KANJI;
 	case OBS_KEY_TOUROKU: return VK_OEM_FJ_TOUROKU;
 	case OBS_KEY_MASSYO: return VK_OEM_FJ_MASSHOU;
 
 	case OBS_KEY_HANGUL: return VK_HANGUL;
 
+	case OBS_KEY_BACKSLASH_RT102: return VK_OEM_102;
+
 	case OBS_KEY_MOUSE1: return VK_LBUTTON;
 	case OBS_KEY_MOUSE2: return VK_RBUTTON;
 	case OBS_KEY_MOUSE3: return VK_MBUTTON;
