@@ -237,6 +237,11 @@ static inline void circlebuf_pop_front(struct circlebuf *cb, void *data,
 	circlebuf_peek_front(cb, data, size);
 
 	cb->size -= size;
+	if (!cb->size) {
+		cb->start_pos = cb->end_pos = 0;
+		return;
+	}
+
 	cb->start_pos += size;
 	if (cb->start_pos >= cb->capacity)
 		cb->start_pos -= cb->capacity;
@@ -248,12 +253,31 @@ static inline void circlebuf_pop_back(struct circlebuf *cb, void *data,
 	circlebuf_peek_front(cb, data, size);
 
 	cb->size -= size;
+	if (!cb->size) {
+		cb->start_pos = cb->end_pos = 0;
+		return;
+	}
+
 	if (cb->end_pos <= size)
 		cb->end_pos = cb->capacity - (size - cb->end_pos);
 	else
 		cb->end_pos -= size;
 }
 
+static inline void *circlebuf_data(struct circlebuf *cb, size_t idx)
+{
+	uint8_t *ptr = (uint8_t*)cb->data;
+	size_t offset = cb->start_pos + idx;
+
+	if (idx > cb->size)
+		return NULL;
+
+	if (offset >= cb->capacity)
+		offset -= cb->capacity;
+
+	return ptr + offset;
+}
+
 #ifdef __cplusplus
 }
 #endif
