@@ -39,6 +39,7 @@ struct ffmpeg_muxer {
 	obs_output_t      *output;
 	os_process_pipe_t *pipe;
 	int64_t           stop_ts;
+	uint64_t          total_bytes;
 	struct dstr       path;
 	bool              sent_headers;
 	volatile bool     active;
@@ -281,10 +282,31 @@ static bool ffmpeg_mux_start(void *data)
 
 	settings = obs_output_get_settings(stream->output);
 	path = obs_data_get_string(settings, "path");
+
+	/* ensure output path is writable to avoid generic error message */
+	/* TODO: remove once ffmpeg-mux is refactored to pass errors back */
+	FILE *test_file = os_fopen(path, "wb");
+	if (!test_file) {
+		struct dstr error_message;
+		dstr_init_copy(&error_message,
+			obs_module_text("UnableToWritePath"));
+		dstr_replace(&error_message, "%1", path);
+		obs_output_set_last_error(stream->output,
+			error_message.array);
+		dstr_free(&error_message);
+		obs_data_release(settings);
+		return false;
+	}
+
+	fclose(test_file);
+	os_unlink(path);
+
 	start_pipe(stream, path);
 	obs_data_release(settings);
 
 	if (!stream->pipe) {
+		obs_output_set_last_error(stream->output,
+			obs_module_text("HelperProcessFailed"));
 		warn("Failed to create process pipe");
 		return false;
 	}
@@ -292,6 +314,7 @@ static bool ffmpeg_mux_start(void *data)
 	/* write headers and start capture */
 	os_atomic_set_bool(&stream->active, true);
 	os_atomic_set_bool(&stream->capturing, true);
+	stream->total_bytes = 0;
 	obs_output_begin_data_capture(stream->output, 0);
 
 	info("Writing file '%s'...", stream->path.array);
@@ -374,6 +397,7 @@ static bool write_packet(struct ffmpeg_muxer *stream,
 		return false;
 	}
 
+	stream->total_bytes += packet->size;
 	return true;
 }
 
@@ -460,6 +484,12 @@ static obs_properties_t *ffmpeg_mux_properties(void *unused)
 	return props;
 }
 
+static uint64_t ffmpeg_mux_total_bytes(void *data)
+{
+	struct ffmpeg_muxer *stream = data;
+	return stream->total_bytes;
+}
+
 struct obs_output_info ffmpeg_muxer = {
 	.id             = "ffmpeg_muxer",
 	.flags          = OBS_OUTPUT_AV |
@@ -471,6 +501,7 @@ struct obs_output_info ffmpeg_muxer = {
 	.start          = ffmpeg_mux_start,
 	.stop           = ffmpeg_mux_stop,
 	.encoded_packet = ffmpeg_mux_data,
+	.get_total_bytes= ffmpeg_mux_total_bytes,
 	.get_properties = ffmpeg_mux_properties
 };
 
@@ -482,7 +513,7 @@ static const char *replay_buffer_getname(void *type)
 	return obs_module_text("ReplayBuffer");
 }
 
-static bool replay_buffer_hotkey(void *data, obs_hotkey_id id,
+static void replay_buffer_hotkey(void *data, obs_hotkey_id id,
 		obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(id);
@@ -492,7 +523,6 @@ static bool replay_buffer_hotkey(void *data, obs_hotkey_id id,
 	struct ffmpeg_muxer *stream = data;
 	if (os_atomic_load_bool(&stream->active))
 		stream->save_ts = os_gettime_ns() / 1000LL;
-	return true;
 }
 
 static void save_replay_proc(void *data, calldata_t *cd)
@@ -503,6 +533,7 @@ static void save_replay_proc(void *data, calldata_t *cd)
 
 static void *replay_buffer_create(obs_data_t *settings, obs_output_t *output)
 {
+	UNUSED_PARAMETER(settings);
 	struct ffmpeg_muxer *stream = bzalloc(sizeof(*stream));
 	stream->output = output;
 
@@ -514,7 +545,6 @@ static void *replay_buffer_create(obs_data_t *settings, obs_output_t *output)
 	proc_handler_t *ph = obs_output_get_proc_handler(output);
 	proc_handler_add(ph, "void save()", save_replay_proc, stream);
 
-	UNUSED_PARAMETER(settings);
 	return stream;
 }
 
@@ -542,6 +572,7 @@ static bool replay_buffer_start(void *data)
 
 	os_atomic_set_bool(&stream->active, true);
 	os_atomic_set_bool(&stream->capturing, true);
+	stream->total_bytes = 0;
 	obs_output_begin_data_capture(stream->output, 0);
 
 	return true;
@@ -811,5 +842,6 @@ struct obs_output_info replay_buffer = {
 	.start          = replay_buffer_start,
 	.stop           = ffmpeg_mux_stop,
 	.encoded_packet = replay_buffer_data,
+	.get_total_bytes= ffmpeg_mux_total_bytes,
 	.get_defaults   = replay_buffer_defaults
 };
