@@ -753,12 +753,7 @@ inline void DShowInput::SetupBuffering(obs_data_t *settings)
 	else
 		useBuffering = bufType == BufferingType::On;
 
-	if (useBuffering)
-		flags &= ~OBS_SOURCE_FLAG_UNBUFFERED;
-	else
-		flags |= OBS_SOURCE_FLAG_UNBUFFERED;
-
-	obs_source_set_flags(source, flags);
+	obs_source_set_async_unbuffered(source, !useBuffering);
 }
 
 static DStr GetVideoFormatName(VideoFormat format);
@@ -852,6 +847,8 @@ bool DShowInput::UpdateVideoConfig(obs_data_t *settings)
 
 	if (videoConfig.internalFormat == VideoFormat::MJPEG) {
 		videoConfig.format = VideoFormat::XRGB;
+		videoConfig.useDefaultConfig = false;
+
 		if (!device.SetVideoConfig(&videoConfig)) {
 			blog(LOG_WARNING, "%s: device.SetVideoConfig (XRGB) "
 					"failed", obs_source_get_name(source));
