@@ -351,7 +351,7 @@ void WASAPISource::Reconnect()
 
 	if (!reconnectThread.Valid())
 		blog(LOG_WARNING, "[WASAPISource::Reconnect] "
-		                "Failed to intiialize reconnect thread: %lu",
+		                "Failed to initialize reconnect thread: %lu",
 		                 GetLastError());
 }
 
@@ -421,6 +421,9 @@ bool WASAPISource::ProcessCaptureData()
 		data.timestamp        = useDeviceTiming ?
 			ts*100 : os_gettime_ns();
 
+		data.timestamp -= (uint64_t)frames * 1000000000ULL /
+			(uint64_t)sampleRate;
+
 		obs_source_output_audio(source, &data);
 
 		capture->ReleaseBuffer(frames);
@@ -590,7 +593,7 @@ void RegisterWASAPIOutput()
 	info.type            = OBS_SOURCE_TYPE_INPUT;
 	info.output_flags    = OBS_SOURCE_AUDIO |
 	                       OBS_SOURCE_DO_NOT_DUPLICATE |
-	                       OBS_SOURCE_DO_NOT_MONITOR;
+	                       OBS_SOURCE_DO_NOT_SELF_MONITOR;
 	info.get_name        = GetWASAPIOutputName;
 	info.create          = CreateWASAPIOutput;
 	info.destroy         = DestroyWASAPISource;
